Introducing georapid for Geospatial Intelligence.
=================================================
Query broadcasted news worldwide and visualize them using spatial aggregations.
This python module represents an idiomatic client accessing the `Geospatial Knowledge APIs <https://geospatial-ai.de/?rara_portfolio_categories=api-services>`__ being hosted on `Rapid API Hub <https://rapidapi.com/hub>`__.
Please, check out the `RapidAPI Account Creation and Management Guide <https://docs.rapidapi.com/docs/account-creation-and-settings>`__.


Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   usage
   api
